2018.12.09 v0.0.1 adding to pypi

2018.01.27 Minor bug fixes
  - Issue #4 - was a temporary traceback during NHL prep of all-star game data that needs handling
  - Issue #3 - formatting change for worse-case CBJ vs VGK
  - Issue #2 - don't show game data if going to show a stream (avoid spoilers)
  - other formatting improvements

2018.01.01 Initial release on github
